@@ -41,18 +41,16 @@ STANDARD_FIELD_ORDER = [
     "c2_socketaddress",
     "c2_address",
     "proxy",
-    "proxy_credential",
-    "proxy_username",
-    "proxy_password",
     "proxy_socketaddress",
     "proxy_address",
-    "proxyport",
     "url",
     "urlpath",
     "socketaddress",
     "address",
     "port",
     "listenport",
+    "ftp",
+    "email_address",
     "credential",
     "username",
     "password",
@@ -61,6 +59,9 @@ STANDARD_FIELD_ORDER = [
     "interval",
     "version",
     "mutex",
+    "pipe",
+    "guid",
+    "event",
     "service",
     "servicename",
     "servicedisplayname",
@@ -71,10 +72,16 @@ STANDARD_FIELD_ORDER = [
     "filepath",
     "directory",
     "filename",
-    "registrykeyvalue",
-    "registrykey",
-    "registryvalue",
+    "registrypath",
+    "registrydata",
+    "registrypathdata",
     "key",
+    "rsa_private_key",
+    "rsa_public_key",
+    "ssl_cert_sha1",
+    "base16_alphabet",
+    "base32_alphabet",
+    "base64_alphabet",
 ]
 
 
